==> exo.ecm.wcm.component.newsletter-1.2rc1-sources.jar: org/exoplatform/services/wcm/newsletter/NewsletterUserInfor.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.wcm.newsletter;

/**
 * Created by The eXo Platform SAS
 * Author : eXoPlatform
 *          ha.mai@exoplatform.com
 * Jun 17, 2009  
 */
public class NewsletterUserInfor {
  String userName;
  String firstName;
  String lastName;
  String email;
  String role;
  
  public String getRole() {
    return role;
  }
  public void setRole(String role) {
    this.role = role;
  }
  public String getUserName() {
    return userName;
  }
  public void setUserName(String userName) {
    this.userName = userName;
  }
  public String getFirstName() {
    return firstName;
  }
  public void setFirstName(String firstName) {
    this.firstName = firstName;
  }
  public String getLastName() {
    return lastName;
  }
  public void setLastName(String lastName) {
    this.lastName = lastName;
  }
  public String getEmail() {
    return email;
  }
  public void setEmail(String email) {
    this.email = email;
  }
}

==> exo.ecm.wcm.component.newsletter-1.2.10-sources.jar: org/exoplatform/services/wcm/newsletter/NewsletterUserInfor.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.wcm.newsletter;

/**
 * Created by The eXo Platform SAS
 * Author : eXoPlatform
 * ha.mai@exoplatform.com
 * Jun 17, 2009
 */
public class NewsletterUserInfor {
  
  /** The user name. */
  String userName;
  
  /** The first name. */
  String firstName;
  
  /** The last name. */
  String lastName;
  
  /** The email. */
  String email;
  
  /** The role. */
  String role;
  
  /**
   * Gets the role.
   * 
   * @return the role
   */
  public String getRole() {
    return role;
  }
  
  /**
   * Sets the role.
   * 
   * @param role the new role
   */
  public void setRole(String role) {
    this.role = role;
  }
  
  /**
   * Gets the user name.
   * 
   * @return the user name
   */
  public String getUserName() {
    return userName;
  }
  
  /**
   * Sets the user name.
   * 
   * @param userName the new user name
   */
  public void setUserName(String userName) {
    this.userName = userName;
  }
  
  /**
   * Gets the first name.
   * 
   * @return the first name
   */
  public String getFirstName() {
    return firstName;
  }
  
  /**
   * Sets the first name.
   * 
   * @param firstName the new first name
   */
  public void setFirstName(String firstName) {
    this.firstName = firstName;
  }
  
  /**
   * Gets the last name.
   * 
   * @return the last name
   */
  public String getLastName() {
    return lastName;
  }
  
  /**
   * Sets the last name.
   * 
   * @param lastName the new last name
   */
  public void setLastName(String lastName) {
    this.lastName = lastName;
  }
  
  /**
   * Gets the email.
   * 
   * @return the email
   */
  public String getEmail() {
    return email;
  }
  
  /**
   * Sets the email.
   * 
   * @param email the new email
   */
  public void setEmail(String email) {
    this.email = email;
  }
}
